==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassSpecFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Any;
import java.lang.Deprecated;
import javax.validation.Valid;
import me.snowdrop.istio.api.AnyBuilder;
import me.snowdrop.istio.api.AnyFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class BypassSpecFluentImpl<A extends BypassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BypassSpecFluent<A>{

    private String backendAddress;
    private AnyBuilder params;
    private Boolean sessionBased;

    public BypassSpecFluentImpl(){
    }
    public BypassSpecFluentImpl(BypassSpec instance){
            this.withBackendAddress(instance.getBackendAddress()); 
            this.withParams(instance.getParams()); 
            this.withSessionBased(instance.getSessionBased()); 
    }

    public String getBackendAddress(){
            return this.backendAddress;
    }

    public A withBackendAddress(String backendAddress){
            this.backendAddress=backendAddress; return (A) this;
    }

    public Boolean hasBackendAddress(){
            return this.backendAddress != null;
    }

    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public Any getParams(){
            return this.params!=null?this.params.build():null;
    }

    public Any buildParams(){
            return this.params!=null?this.params.build():null;
    }

    public A withParams(Any params){
            _visitables.remove(this.params);
            if (params!=null){ this.params= new AnyBuilder(params); _visitables.add(this.params);} return (A) this;
    }

    public Boolean hasParams(){
            return this.params != null;
    }

    public A withNewParams(String typeUrl,String value){
            return (A)withParams(new Any(typeUrl, value));
    }

    public BypassSpecFluent.ParamsNested<A> withNewParams(){
            return new ParamsNestedImpl();
    }

    public BypassSpecFluent.ParamsNested<A> withNewParamsLike(Any item){
            return new ParamsNestedImpl(item);
    }

    public BypassSpecFluent.ParamsNested<A> editParams(){
            return withNewParamsLike(getParams());
    }

    public BypassSpecFluent.ParamsNested<A> editOrNewParams(){
            return withNewParamsLike(getParams() != null ? getParams(): new AnyBuilder().build());
    }

    public BypassSpecFluent.ParamsNested<A> editOrNewParamsLike(Any item){
            return withNewParamsLike(getParams() != null ? getParams(): item);
    }

    public Boolean isSessionBased(){
            return this.sessionBased;
    }

    public A withSessionBased(Boolean sessionBased){
            this.sessionBased=sessionBased; return (A) this;
    }

    public Boolean hasSessionBased(){
            return this.sessionBased != null;
    }

    public A withNewSessionBased(String arg1){
            return (A)withSessionBased(new Boolean(arg1));
    }

    public A withNewSessionBased(boolean arg1){
            return (A)withSessionBased(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            BypassSpecFluentImpl that = (BypassSpecFluentImpl) o;
            if (backendAddress != null ? !backendAddress.equals(that.backendAddress) :that.backendAddress != null) return false;
            if (params != null ? !params.equals(that.params) :that.params != null) return false;
            if (sessionBased != null ? !sessionBased.equals(that.sessionBased) :that.sessionBased != null) return false;
            return true;
    }


    public class ParamsNestedImpl<N> extends AnyFluentImpl<BypassSpecFluent.ParamsNested<N>> implements BypassSpecFluent.ParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final AnyBuilder builder;
    
            ParamsNestedImpl(Any item){
                    this.builder = new AnyBuilder(this, item);
            }
            ParamsNestedImpl(){
                    this.builder = new AnyBuilder(this);
            }
    
    public N and(){
            return (N) BypassSpecFluentImpl.this.withParams(builder.build());
    }
    public N endParams(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassSpecFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.Any;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import me.snowdrop.istio.api.AnyBuilder;
import me.snowdrop.istio.api.AnyFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class BypassSpecFluentImpl<A extends BypassSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BypassSpecFluent<A>{

    private String backendAddress;
    private AnyBuilder params;
    private Boolean sessionBased;

    public BypassSpecFluentImpl(){
    }
    public BypassSpecFluentImpl(BypassSpec instance){
            this.withBackendAddress(instance.getBackendAddress()); 
            this.withParams(instance.getParams()); 
            this.withSessionBased(instance.getSessionBased()); 
    }

    public String getBackendAddress(){
            return this.backendAddress;
    }

    public A withBackendAddress(String backendAddress){
            this.backendAddress=backendAddress; return (A) this;
    }

    public Boolean hasBackendAddress(){
            return this.backendAddress != null;
    }

    public A withNewBackendAddress(String arg1){
            return (A)withBackendAddress(new String(arg1));
    }

    public A withNewBackendAddress(StringBuilder arg1){
            return (A)withBackendAddress(new String(arg1));
    }

    public A withNewBackendAddress(StringBuffer arg1){
            return (A)withBackendAddress(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public Any getParams(){
            return this.params!=null?this.params.build():null;
    }

    public Any buildParams(){
            return this.params!=null?this.params.build():null;
    }

    public A withParams(Any params){
            _visitables.get("params").remove(this.params);
            if (params!=null){ this.params= new AnyBuilder(params); _visitables.get("params").add(this.params);} return (A) this;
    }

    public Boolean hasParams(){
            return this.params != null;
    }

    public A withNewParams(String typeUrl,String value){
            return (A)withParams(new Any(typeUrl, value));
    }

    public BypassSpecFluent.ParamsNested<A> withNewParams(){
            return new ParamsNestedImpl();
    }

    public BypassSpecFluent.ParamsNested<A> withNewParamsLike(Any item){
            return new ParamsNestedImpl(item);
    }

    public BypassSpecFluent.ParamsNested<A> editParams(){
            return withNewParamsLike(getParams());
    }

    public BypassSpecFluent.ParamsNested<A> editOrNewParams(){
            return withNewParamsLike(getParams() != null ? getParams(): new AnyBuilder().build());
    }

    public BypassSpecFluent.ParamsNested<A> editOrNewParamsLike(Any item){
            return withNewParamsLike(getParams() != null ? getParams(): item);
    }

    public Boolean isSessionBased(){
            return this.sessionBased;
    }

    public A withSessionBased(Boolean sessionBased){
            this.sessionBased=sessionBased; return (A) this;
    }

    public Boolean hasSessionBased(){
            return this.sessionBased != null;
    }

    public A withNewSessionBased(String arg1){
            return (A)withSessionBased(new Boolean(arg1));
    }

    public A withNewSessionBased(boolean arg1){
            return (A)withSessionBased(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            BypassSpecFluentImpl that = (BypassSpecFluentImpl) o;
            if (backendAddress != null ? !backendAddress.equals(that.backendAddress) :that.backendAddress != null) return false;
            if (params != null ? !params.equals(that.params) :that.params != null) return false;
            if (sessionBased != null ? !sessionBased.equals(that.sessionBased) :that.sessionBased != null) return false;
            return true;
    }


    public class ParamsNestedImpl<N> extends AnyFluentImpl<BypassSpecFluent.ParamsNested<N>> implements BypassSpecFluent.ParamsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final AnyBuilder builder;
    
            ParamsNestedImpl(Any item){
                    this.builder = new AnyBuilder(this, item);
            }
            ParamsNestedImpl(){
                    this.builder = new AnyBuilder(this);
            }
    
    public N and(){
            return (N) BypassSpecFluentImpl.this.withParams(builder.build());
    }
    public N endParams(){
            return and();
    }

}


}
